@@ -21,7 +21,7 @@ try:
 
     NUM_DATA_TYPES = [numpy.int8, numpy.int16, numpy.int32, numpy.int64,
                       numpy.float16, numpy.float32, numpy.float64,
-                      numpy.uint8, numpy.uint16, numpy.uint32, numpy.uint64]
+                      numpy.uint8, numpy.uint16, numpy.uint32, numpy.uint64, numpy.bool_]
 except:
     numpy = None
 
