@@ -49,6 +49,8 @@ DESC_TABLE_RE = re.compile(u(r'desc(?:ribe)?\s+([\w_]+)\s*;?\s*$'),
 
 logger = getLogger(__name__)
 
+LOG_MAX_QUERY_LENGTH = 80
+
 
 class SnowflakeCursor(object):
     u"""
@@ -65,8 +67,6 @@ class SnowflakeCursor(object):
         u(r'alter\s+session\s+set\s+(.*)=\'?([^\']+)\'?\s*;'),
         flags=re.IGNORECASE | re.MULTILINE | re.DOTALL)
 
-    LOG_MAX_QUERY_LENGTH = 80
-
     def __init__(self, connection):
         self._connection = connection
 
@@ -97,6 +97,8 @@ class SnowflakeCursor(object):
 
         self._first_chunk_time = None
 
+        self._log_max_query_length = connection.log_max_query_length
+
         self.reset()
 
     def __del__(self):
@@ -303,9 +305,7 @@ class SnowflakeCursor(object):
 
         if logger.getEffectiveLevel() <= logging.DEBUG:
             logger.debug(
-                u'running query [%s]',
-                u' '.join(line.strip() for line in query.split(u'\n')),
-            )
+                u'running query [%s]', self._format_query_for_log(query))
         if _is_put_get is not None:
             # if told the query is PUT or GET, use the information
             self._is_file_transfer = _is_put_get
@@ -375,6 +375,9 @@ class SnowflakeCursor(object):
                 logger.debug(
                     u'Failed to reset SIGINT handler. Not in main '
                     u'thread. Ignored...')
+            except Exception:
+                self.connection.incident.report_incident()
+                raise
             if self._timebomb is not None:
                 self._timebomb.cancel()
                 logger.debug(u'cancelled timebomb in finally')
@@ -437,24 +440,29 @@ class SnowflakeCursor(object):
             logger.warning(u'execute: no query is given to execute')
             return
 
-        if self._connection.is_pyformat:
-            # pyformat/format paramstyle
-            # client side binding
-            processed_params = self._connection._process_params(params, self)
-            logger.debug(u'binding: %s with input=%s, processed=%s',
-                         command,
-                         params, processed_params)
-            if len(processed_params) > 0:
-                query = command % processed_params
+        try:
+            if self._connection.is_pyformat:
+                # pyformat/format paramstyle
+                # client side binding
+                processed_params = self._connection._process_params(params, self)
+                if logger.getEffectiveLevel() <= logging.DEBUG:
+                    logger.debug(u'binding: [%s] with input=[%s], processed=[%s]',
+                                 self._format_query_for_log(command),
+                                 params, processed_params)
+                if len(processed_params) > 0:
+                    query = command % processed_params
+                else:
+                    query = command
+                processed_params = None  # reset to None
             else:
+                # qmark and numeric paramstyle
+                # server side binding
                 query = command
-            processed_params = None  # reset to None
-        else:
-            # qmark and numeric paramstyle
-            # server side binding
-            query = command
-            processed_params = self._connection._process_params_qmarks(
-                params, self)
+                processed_params = self._connection._process_params_qmarks(
+                    params, self)
+        except Exception:
+            self.connection.incident.report_incident()
+            raise
 
         m = DESC_TABLE_RE.match(query)
         if m:
@@ -551,9 +559,7 @@ class SnowflakeCursor(object):
         return self
 
     def _format_query_for_log(self, query):
-        ret = u' '.join(line.strip() for line in query.split(u'\n'))
-        return (ret if len(ret) < SnowflakeCursor.LOG_MAX_QUERY_LENGTH
-                else ret[0:SnowflakeCursor.LOG_MAX_QUERY_LENGTH] + '...')
+        return self._connection._format_query_for_log(query)
 
     def _is_dml(self, data):
         return u'statementTypeId' in data \
