@@ -21,7 +21,7 @@ from asn1crypto.x509 import Certificate
 from snowflake.connector.errorcode import (
     ER_INVALID_OCSP_RESPONSE,
     ER_INVALID_OCSP_RESPONSE_CODE)
-from snowflake.connector.errors import OperationalError
+from snowflake.connector.errors import RevocationCheckError
 from snowflake.connector.ocsp_snowflake import SnowflakeOCSP
 from collections import OrderedDict
 from snowflake.connector.ssd_internal_keys import ret_wildcard_hkey
@@ -148,7 +148,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         res = OCSPResponse.load(ocsp_response)
 
         if res['response_status'].native != 'successful':
-            raise OperationalError(
+            raise RevocationCheckError(
                 msg="Invalid Status: {0}".format(res['response_status'].native),
                 errno=ER_INVALID_OCSP_RESPONSE)
 
@@ -171,12 +171,12 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         try:
             res = OCSPResponse.load(ocsp_response)
         except Exception:
-            raise OperationalError(
+            raise RevocationCheckError(
                 msg='Invalid OCSP Response',
                 errno=ER_INVALID_OCSP_RESPONSE
             )
         if res['response_status'].native != 'successful':
-            raise OperationalError(
+            raise RevocationCheckError(
                 msg="Invalid Status: {0}".format(res['response_status'].native),
                 errno=ER_INVALID_OCSP_RESPONSE)
 
@@ -194,16 +194,17 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
 
             if cur_time > ocsp_cert['tbs_certificate']['validity']['not_after'].native or \
                     cur_time < ocsp_cert['tbs_certificate']['validity']['not_before'].native:
-                raise OperationalError(
-                    msg="Certificate attached to OCSP response is invalid. OCSP response "
-                    "current time - {0} "
-                    "certificate not before time - {1} "
-                    "certificate not after time - {2}".
-                        format(cur_time,
-                               ocsp_cert['tbs_certificate']['validity']['not_before'].native,
-                               ocsp_cert['tbs_certificate']['validity']['not_after'].native),
-                    errno=ER_INVALID_OCSP_RESPONSE_CODE
-                )
+                debug_msg = "Certificate attached to OCSP response is invalid. OCSP response " \
+                            "current time - {0} certificate not before time - {1} certificate " \
+                            "not after time - {2}. Consider running curl -o ocsp.der {3}".\
+                    format(cur_time,
+                           ocsp_cert['tbs_certificate']['validity']['not_before'].native,
+                           ocsp_cert['tbs_certificate']['validity']['not_after'].native,
+                           super(SnowflakeOCSPAsn1Crypto, self).debug_ocsp_failure_url)
+
+                raise RevocationCheckError(
+                    msg=debug_msg,
+                    errno=ER_INVALID_OCSP_RESPONSE_CODE)
 
             self.verify_signature(
                 ocsp_cert.hash_algo,
@@ -227,19 +228,27 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
 
         single_response = tbs_response_data['responses'][0]
         cert_status = single_response['cert_status'].name
-        if cert_status == 'good':
-            self._process_good_status(single_response, cert_id, ocsp_response)
-            SnowflakeOCSP.OCSP_CACHE.update_cache(self, cert_id, ocsp_response)
-        elif cert_status == 'revoked':
-            self._process_revoked_status(single_response, cert_id)
-        elif cert_status == 'unknown':
-            self._process_unknown_status(cert_id)
-        else:
-            raise OperationalError(
-                msg="Unknown revocation status was returned. OCSP response "
-                    "may be malformed: {0}".format(cert_status),
-                errno=ER_INVALID_OCSP_RESPONSE_CODE
-            )
+        try:
+            if cert_status == 'good':
+                self._process_good_status(single_response, cert_id, ocsp_response)
+                SnowflakeOCSP.OCSP_CACHE.update_cache(self, cert_id, ocsp_response)
+            elif cert_status == 'revoked':
+                self._process_revoked_status(single_response, cert_id)
+            elif cert_status == 'unknown':
+                self._process_unknown_status(cert_id)
+            else:
+                debug_msg = "Unknown revocation status was returned." \
+                            "OCSP response may be malformed: {0}.".\
+                    format(cert_status)
+                raise RevocationCheckError(
+                    msg=debug_msg,
+                    errno=ER_INVALID_OCSP_RESPONSE_CODE
+                )
+        except RevocationCheckError as op_er:
+            debug_msg = "{0} Consider running curl -o ocsp.der {1}".\
+                format(op_er.msg,
+                           self.debug_ocsp_failure_url)
+            raise RevocationCheckError(msg=debug_msg, errno=op_er.errno)
 
     def verify_signature(self, signature_algorithm, signature, cert, data):
         pubkey = cert.public_key.unwrap().dump()
@@ -254,7 +263,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
             digest = SHA1.new()
         digest.update(data.dump())
         if not signer.verify(digest, signature):
-            raise OperationalError(
+            raise RevocationCheckError(
                 msg="Failed to verify the signature",
                 errno=ER_INVALID_OCSP_RESPONSE)
 
@@ -297,7 +306,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
                 self._lazy_read_ca_bundle()
                 logger.debug('not found issuer_der: %s', subject.issuer.native)
                 if issuer_hash not in SnowflakeOCSP.ROOT_CERTIFICATES_DICT:
-                    raise OperationalError(
+                    raise RevocationCheckError(
                         msg="CA certificate is NOT found in the root "
                             "certificate list. Make sure you use the latest "
                             "Python Connector package and the URL is valid.")
